@@ -12,16 +12,15 @@
 (*                                                                     *)
 (***********************************************************************)
 
-(* $Id: oGif.ml,v 1.7 2004/09/07 07:31:04 weis Exp $ *)
+(* $Id: oGif.ml,v 1.2 2008/06/16 22:35:42 furuse Exp $ *)
 
-open OImages;;
-open Gif;;
+open OImages
 
-let load_first name opts = OImages.make (Gif.load_first name opts);;
+let load_first name opts = OImages.make (Gif.load_first name opts)
 
 let save_image name opts image =
   let img = image#image in
   match img with
-  | Images.Index8 bmp ->
+  | Images.Index8 _bmp ->
       Gif.save_image name opts img
-  | _ -> raise Wrong_image_class;;
+  | _ -> raise Wrong_image_class
