@@ -10,12 +10,10 @@
 (*                                                                     *)
 (***********************************************************************)
 
-(* $Id: oPng.ml,v 1.8 2004/09/07 07:31:06 weis Exp $ *)
+(* $Id: oPng.ml,v 1.1 2007/01/18 10:29:57 rousse Exp $ *)
 
-open OImages;;
+let load_as_rgb24 name opts = OImages.make (Png.load_as_rgb24 name opts)
 
-let load_as_rgb24 name opts = OImages.make (Png.load_as_rgb24 name opts);;
+let load name opts = OImages.make (Png.load name opts)
 
-let load name opts = OImages.make (Png.load name opts);;
-
-let save name opts image = Png.save name opts image#image;;
+let save name opts image = Png.save name opts image#image
