@@ -1,3 +1,4 @@
+
 (***********************************************************************)
 (*                                                                     *)
 (*                           Objective Caml                            *)
@@ -12,56 +13,59 @@
 (*                                                                     *)
 (***********************************************************************)
 
-(* $Id: tiff.ml,v 1.11 2004/09/07 07:31:07 weis Exp $ *)
+(* $Id: tiff.ml,v 1.2 2008/06/16 22:35:42 furuse Exp $ *)
 
-open Images;;
-open Rgb24;;
+open Images
+open Rgb24
+open Util
 
-type colormodel = RGB | CMYK | WHITEBLACK | BLACKWHITE;;
+module Pervasives = Stdlib
 
-type in_handle;;
+type colormodel = RGB | CMYK | WHITEBLACK | BLACKWHITE
+
+type in_handle
 
 external open_in : string -> int * int * float * colormodel * in_handle
-    = "open_tiff_file_for_read";;
-external read_scanline : in_handle -> string -> int -> unit
-    = "read_tiff_scanline";;
+    = "open_tiff_file_for_read"
+external read_scanline : in_handle -> bytes -> int -> unit
+    = "read_tiff_scanline"
 external close_in : in_handle -> unit
-    = "close_tiff_file";;
+    = "close_tiff_file"
 
-type out_handle;;
+type out_handle
 
 external open_out : string -> int -> int -> float -> out_handle
-    = "open_tiff_file_for_write";;
-external write_scanline : out_handle -> string -> int -> unit
-    = "write_tiff_scanline";;
+    = "open_tiff_file_for_write"
+external write_scanline : out_handle -> bytes -> int -> unit
+    = "write_tiff_scanline"
 external close_out : out_handle -> unit
-    = "close_tiff_file";;
+    = "close_tiff_file"
 
 let load name opts =
   let prog = Images.load_progress opts in
-  let w, h, dpi, colormodel, tif = open_in name in
+  let w, h, _dpi, colormodel, tif = open_in name in
   let img, buf =
     match colormodel with
     | RGB ->
       	let img = Rgb24.create w h in
 	Rgb24 img,
-      	String.create (w * 3)
+      	Bytes.create (w * 3)
     | CMYK ->
 	let img = Cmyk32.create w h in
 	Cmyk32 img,
-      	String.create (w * 4)
+      	Bytes.create (w * 4)
     | WHITEBLACK ->
 	let img = Index8.create w h in
 	img.Index8.colormap.map <- [| {r = 255; g = 255; b = 255};
 				      {r = 0; g = 0; b = 0} |];
 	Index8 img,
-	String.create ((w + 7) / 8)
+	Bytes.create ((w + 7) / 8)
     | BLACKWHITE ->
 	let img = Index8.create w h in
 	img.Index8.colormap.map <- [| {r = 0; g = 0; b = 0};
 				      {r = 255; g = 255; b = 255} |];
 	Index8 img,
-	String.create ((w + 7) / 8) in
+	Bytes.create ((w + 7) / 8) in
 
   let set_scanline =
     match colormodel, img with
@@ -74,7 +78,7 @@ let load name opts =
 	  for x = 0 to w - 1 do
 	    let c = x lsr 3 in
 	    let b = x land 7 in
-	    if Char.code buf.[c] land Array.unsafe_get bits b <> 0 then
+	    if (buf @% c) land Array.unsafe_get bits b <> 0 then
 	      Index8.unsafe_set img x y 1
 	  done
     | _ -> assert false in
@@ -87,9 +91,9 @@ let load name opts =
     | None -> ()
   done;
   close_in tif;
-  img;;
+  img
 
-let save name opts image =
+let save name _opts image =
   match image with
   | Rgb24 bmp ->
       let resolution = (* resolution in DPI *)
@@ -101,16 +105,16 @@ let save name opts image =
 	write_scanline oc (Rgb24.get_scanline bmp y) y
       done;
       close_out oc
-  | _ -> raise Wrong_image_type;;
+  | _ -> raise Wrong_image_type
 
 let check_header filename =
   let len = 4 in
   let ic = open_in_bin filename in
   try
-    let str = String.create len in
+    let str = Bytes.create len in
     really_input ic str 0 len;
     Pervasives.close_in ic;
-    match str with
+    match Bytes.to_string str with
     | "MM\000\042" ->
       { header_width = -1;
   	header_height = -1;
@@ -123,13 +127,13 @@ let check_header filename =
   with
   | _ ->
       Pervasives.close_in ic;
-      raise Wrong_file_type;;
+      raise Wrong_file_type
 
-add_methods Tiff
+let () = add_methods Tiff
   { check_header = check_header;
     load = Some load;
     save = Some save;
     load_sequence = None;
     save_sequence = None;
-};;
+}
 
