@@ -10,8 +10,6 @@
 (*                                                                     *)
 (***********************************************************************)
 
-(* $Id: oXpm.ml,v 1.7 2004/09/07 07:31:08 weis Exp $ *)
+(* $Id: oXpm.ml,v 1.1 2007/01/18 10:29:57 rousse Exp $ *)
 
-open OImages;;
-
-let load name opts = OImages.make (Xpm.load name opts);;
+let load name opts = OImages.make (Xpm.load name opts)
